@@ -1,7 +1,8 @@
 """ Sphinxtesters package
 """
 
-from .sphinxutils import (SourcesBuilder, ModifiedPageBuilder, TempApp)
+from .sphinxutils import (PageBuilder, SourcesBuilder, ModifiedPageBuilder,
+                          TempApp)
 
 from ._version import get_versions
 __version__ = get_versions()['version']
