@@ -4,8 +4,6 @@ from os.path import (join as pjoin, dirname, isdir, exists, splitext)
 
 from sphinxtesters import ModifiedPageBuilder
 
-from nose.tools import assert_true, assert_equal
-
 HERE = dirname(__file__)
 
 
@@ -22,15 +20,15 @@ class Proj1Builder(ModifiedPageBuilder):
 class TestProj1(Proj1Builder):
 
     def test_basic_build(self):
-        assert_true(isdir(self.out_dir))
-        assert_true(isdir(self.doctree_dir))
+        assert isdir(self.out_dir)
+        assert isdir(self.doctree_dir)
         doctree = self.get_doctree(splitext(self.default_page)[0])
-        assert_equal(len(doctree.document), 1)
+        assert len(doctree.document) == 1
         doctree_str = self.doctree2str(doctree)
         expected = (
             '<title>A section</title>\n'
             '<paragraph>Some text.</paragraph>\n'
             '<paragraph>More text.</paragraph>\n'
             '<paragraph>Text is endless.</paragraph>')
-        assert_equal(doctree_str, expected)
-        assert_true(exists(pjoin(self.doctree_dir, 'index.doctree')))
+        assert doctree_str == expected
+        assert exists(pjoin(self.doctree_dir, 'index.doctree'))
